==> webkit2gtk_2.51.2.orig.tar.xz: webkitgtk-2.51.2/Source/WebCore/Modules/mediastream/RTCRtpSFrameTransformErrorEvent.h <==
/*
 * Copyright (C) 2021-2024 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEB_RTC)

#include "Event.h"

namespace WebCore {

class RTCRtpSFrameTransformErrorEvent final : public Event {
    WTF_MAKE_TZONE_OR_ISO_ALLOCATED(RTCRtpSFrameTransformErrorEvent);
public:
    virtual ~RTCRtpSFrameTransformErrorEvent();

    enum Type { Authentication, KeyID, Syntax };

    struct Init : EventInit {
        Type errorType;
    };

    static Ref<RTCRtpSFrameTransformErrorEvent> create(const AtomString& type, Init&&);
    static Ref<RTCRtpSFrameTransformErrorEvent> create(CanBubble, IsCancelable, Type);

    Type errorType() const { return m_errorType; }

private:
    RTCRtpSFrameTransformErrorEvent(const AtomString& type, CanBubble, IsCancelable, Type);

    Type m_errorType;
};

} // namespace WebCore

#endif // ENABLE(WEB_RTC)

==> webkit2gtk_2.51.92.orig.tar.xz: webkitgtk-2.51.92/Source/WebCore/Modules/mediastream/RTCRtpSFrameTransformErrorEvent.h <==
/*
 * Copyright (C) 2021-2024 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEB_RTC)

#include "Event.h"

namespace WebCore {

class RTCRtpSFrameTransformErrorEvent final : public Event {
    WTF_MAKE_TZONE_ALLOCATED(RTCRtpSFrameTransformErrorEvent);
public:
    virtual ~RTCRtpSFrameTransformErrorEvent();

    enum class Type : uint8_t { Authentication, KeyID, Syntax };

    struct Init : EventInit {
        Type errorType;
    };

    static Ref<RTCRtpSFrameTransformErrorEvent> create(const AtomString& type, Init&&);
    static Ref<RTCRtpSFrameTransformErrorEvent> create(CanBubble, IsCancelable, Type);

    Type errorType() const { return m_errorType; }

private:
    RTCRtpSFrameTransformErrorEvent(const AtomString& type, CanBubble, IsCancelable, Type);

    Type m_errorType;
};

} // namespace WebCore

#endif // ENABLE(WEB_RTC)
